@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -719,7 +719,7 @@ class Stereographic(CoordSystem):
         return ccrs.Stereographic(
             self.central_lat, self.central_lon,
             self.false_easting, self.false_northing,
-            self.true_scale_lat, globe)
+            self.true_scale_lat, globe=globe)
 
     def as_cartopy_projection(self):
         return self.as_cartopy_crs()
@@ -831,7 +831,8 @@ class Mercator(CoordSystem):
 
     grid_mapping_name = "mercator"
 
-    def __init__(self, longitude_of_projection_origin=0, ellipsoid=None):
+    def __init__(self, longitude_of_projection_origin=0.0, ellipsoid=None,
+                 standard_parallel=0.0):
         """
         Constructs a Mercator coord system.
 
@@ -840,17 +841,23 @@ class Mercator(CoordSystem):
                     True longitude of planar origin in degrees.
             * ellipsoid
                     :class:`GeogCS` defining the ellipsoid.
+            * standard_parallel
+                    the latitude where the scale is 1. Defaults to 0 degrees.
 
         """
-
         #: True longitude of planar origin in degrees.
         self.longitude_of_projection_origin = longitude_of_projection_origin
         #: Ellipsoid definition.
         self.ellipsoid = ellipsoid
+        #: The latitude where the scale is 1 (defaults to 0 degrees).
+        self.standard_parallel = standard_parallel
 
     def __repr__(self):
-        res = "Mercator(longitude_of_projection_origin={!r}, ellipsoid={!r})"
-        return res.format(self.longitude_of_projection_origin, self.ellipsoid)
+        res = ("Mercator(longitude_of_projection_origin="
+               "{self.longitude_of_projection_origin!r}, "
+               "ellipsoid={self.ellipsoid!r}, "
+               "standard_parallel={self.standard_parallel!r})")
+        return res.format(self=self)
 
     def as_cartopy_crs(self):
         if self.ellipsoid is not None:
@@ -860,7 +867,8 @@ class Mercator(CoordSystem):
 
         return ccrs.Mercator(
             central_longitude=self.longitude_of_projection_origin,
-            globe=globe)
+            globe=globe,
+            latitude_true_scale=self.standard_parallel)
 
     def as_cartopy_projection(self):
         return self.as_cartopy_crs()
@@ -934,3 +942,84 @@ class LambertAzimuthalEqualArea(CoordSystem):
 
     def as_cartopy_projection(self):
         return self.as_cartopy_crs()
+
+
+class AlbersEqualArea(CoordSystem):
+    """
+    A coordinate system in the Albers Conical Equal Area projection.
+
+    """
+
+    grid_mapping_name = "albers_conical_equal_area"
+
+    def __init__(self, latitude_of_projection_origin=0.0,
+                 longitude_of_central_meridian=0.0,
+                 false_easting=0.0, false_northing=0.0,
+                 standard_parallels=(20.0, 50.0),
+                 ellipsoid=None):
+        """
+        Constructs a Albers Conical Equal Area coord system.
+
+        Kwargs:
+
+            * latitude_of_projection_origin
+                    True latitude of planar origin in degrees.
+                    Defaults to 0.
+
+            * longitude_of_central_meridian
+                    True longitude of planar central meridian in degrees.
+                    Defaults to 0.
+
+            * false_easting
+                    X offset from planar origin in metres. Defaults to 0.
+
+            * false_northing
+                    Y offset from planar origin in metres. Defaults to 0.
+
+            * standard_parallels
+                    The one or two latitudes of correct scale.
+                    Defaults to (20,50).
+            * ellipsoid
+                    :class:`GeogCS` defining the ellipsoid.
+
+        """
+        #: True latitude of planar origin in degrees.
+        self.latitude_of_projection_origin = latitude_of_projection_origin
+        #: True longitude of planar central meridian in degrees.
+        self.longitude_of_central_meridian = longitude_of_central_meridian
+        #: X offset from planar origin in metres.
+        self.false_easting = false_easting
+        #: Y offset from planar origin in metres.
+        self.false_northing = false_northing
+        #: The one or two latitudes of correct scale.
+        self.standard_parallels = standard_parallels
+        #: Ellipsoid definition.
+        self.ellipsoid = ellipsoid
+
+    def __repr__(self):
+        return ("AlbersEqualArea(latitude_of_projection_origin={!r},"
+                " longitude_of_central_meridian={!r}, false_easting={!r},"
+                " false_northing={!r}, standard_parallels={!r},"
+                " ellipsoid={!r})").format(
+                    self.latitude_of_projection_origin,
+                    self.longitude_of_central_meridian,
+                    self.false_easting,
+                    self.false_northing,
+                    self.standard_parallels,
+                    self.ellipsoid)
+
+    def as_cartopy_crs(self):
+        if self.ellipsoid is not None:
+            globe = self.ellipsoid.as_cartopy_globe()
+        else:
+            globe = ccrs.Globe()
+        return ccrs.AlbersEqualArea(
+            central_longitude=self.longitude_of_central_meridian,
+            central_latitude=self.latitude_of_projection_origin,
+            false_easting=self.false_easting,
+            false_northing=self.false_northing,
+            standard_parallels=self.standard_parallels,
+            globe=globe)
+
+    def as_cartopy_projection(self):
+        return self.as_cartopy_crs()
