@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -32,13 +32,13 @@ import operator
 import warnings
 import zlib
 
-import netcdftime
+import cftime
 import numpy as np
 import numpy.ma as ma
 
 from iris._data_manager import DataManager
 from iris._deprecation import warn_deprecated
-from iris._lazy_data import as_concrete_data, is_lazy_data, multidim_lazy_stack
+import iris._lazy_data as _lazy
 import iris.aux_factory
 import iris.exceptions
 import iris.time
@@ -267,13 +267,13 @@ class Cell(collections.namedtuple('Cell', ['point', 'bound'])):
                                    operator.ge, operator.le):
             raise ValueError("Unexpected operator_method")
 
-        # Prevent silent errors resulting from missing netcdftime
+        # Prevent silent errors resulting from missing cftime
         # behaviour.
-        if (isinstance(other, netcdftime.datetime) or
-                (isinstance(self.point, netcdftime.datetime) and
+        if (isinstance(other, cftime.datetime) or
+                (isinstance(self.point, cftime.datetime) and
                  not isinstance(other, iris.time.PartialDateTime))):
             raise TypeError('Cannot determine the order of '
-                            'netcdftime.datetime objects')
+                            'cftime.datetime objects')
 
         if isinstance(other, Cell):
             # Cell vs Cell comparison for providing a strict sort order
@@ -336,7 +336,7 @@ class Cell(collections.namedtuple('Cell', ['point', 'bound'])):
                 else:
                     me = max(self.bound)
 
-            # Work around to handle netcdftime.datetime comparison, which
+            # Work around to handle cftime.datetime comparison, which
             # doesn't return NotImplemented on failure in some versions of the
             # library
             try:
@@ -418,11 +418,11 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         Kwargs:
 
         * standard_name:
-            CF standard name of coordinate
+            CF standard name of the coordinate.
         * long_name:
-            Descriptive name of coordinate
+            Descriptive name of the coordinate.
         * var_name:
-            CF variable name of coordinate
+            The netCDF variable name for the coordinate.
         * units
             The :class:`~cf_units.Unit` of the coordinate's values.
             Can be a string, which will be converted to a Unit object.
@@ -446,7 +446,7 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         #: Descriptive name of the coordinate.
         self.long_name = long_name
 
-        #: The CF variable name for the coordinate.
+        #: The netCDF variable name for the coordinate.
         self.var_name = var_name
 
         #: Unit of the quantity that the coordinate represents.
@@ -553,7 +553,7 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         return cls(**kwargs)
 
     def _sanitise_array(self, src, ndmin):
-        if is_lazy_data(src):
+        if _lazy.is_lazy_data(src):
             # Lazy data : just ensure ndmin requirement.
             ndims_missing = ndmin - src.ndim
             if ndims_missing <= 0:
@@ -671,7 +671,7 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
 
         """
         result = self._points_dm.core_data()
-        if not is_lazy_data(result):
+        if not _lazy.is_lazy_data(result):
             result = result.view()
         return result
 
@@ -684,7 +684,7 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         result = None
         if self.has_bounds():
             result = self._bounds_dm.core_data()
-            if not is_lazy_data(result):
+            if not _lazy.is_lazy_data(result):
                 result = result.view()
         return result
 
@@ -732,7 +732,13 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
             fmt = '{cls}({points}{bounds}' \
                   ', standard_name={self.standard_name!r}' \
                   ', calendar={self.units.calendar!r}{other_metadata})'
-            points = self._str_dates(self.points)
+            if self.units.is_long_time_interval():
+                # A time unit with a long time interval ("months" or "years")
+                # cannot be converted to a date using `num2date` so gracefully
+                # fall back to printing points as numbers, not datetimes.
+                points = self.points
+            else:
+                points = self._str_dates(self.points)
             bounds = ''
             if self.has_bounds():
                 bounds = ', bounds=' + self._str_dates(self.bounds)
@@ -908,9 +914,28 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
             raise iris.exceptions.UnitConversionError(
                 'Cannot convert from unknown units. '
                 'The "coord.units" attribute may be set directly.')
-        self.points = self.units.convert(self.points, unit)
+        if self.has_lazy_points() or self.has_lazy_bounds():
+            # Make fixed copies of old + new units for a delayed conversion.
+            old_unit = self.units
+            new_unit = unit
+
+            # Define a delayed conversion operation (i.e. a callback).
+            def pointwise_convert(values):
+                return old_unit.convert(values, new_unit)
+
+        if self.has_lazy_points():
+            new_points = _lazy.lazy_elementwise(self.lazy_points(),
+                                                pointwise_convert)
+        else:
+            new_points = self.units.convert(self.points, unit)
+        self.points = new_points
         if self.has_bounds():
-            self.bounds = self.units.convert(self.bounds, unit)
+            if self.has_lazy_bounds():
+                new_bounds = _lazy.lazy_elementwise(self.lazy_bounds(),
+                                                    pointwise_convert)
+            else:
+                new_bounds = self.units.convert(self.bounds, unit)
+            self.bounds = new_bounds
         self.units = unit
 
     def cells(self):
@@ -1102,7 +1127,7 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
             If `iris.FUTURE.cell_datetime_objects` is True, then this
             method will return Cell objects whose `points` and `bounds`
             attributes contain either datetime.datetime instances or
-            netcdftime.datetime instances (depending on the calendar).
+            cftime.datetime instances (depending on the calendar).
 
         .. deprecated:: 2.0.0
 
@@ -1144,22 +1169,16 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         the specified dimensions.
 
         Replaces the points & bounds with a simple bounded region.
-
-        .. note::
-            You cannot partially collapse a multi-dimensional coordinate. See
-            :ref:`cube.collapsed <partially_collapse_multi-dim_coord>` for more
-            information.
-
         """
+        import dask.array as da
+        # Ensure dims_to_collapse is a tuple to be able to pass
+        # through to numpy
         if isinstance(dims_to_collapse, (int, np.integer)):
-            dims_to_collapse = [dims_to_collapse]
+            dims_to_collapse = (dims_to_collapse, )
+        if isinstance(dims_to_collapse, list):
+            dims_to_collapse = tuple(dims_to_collapse)
 
-        if dims_to_collapse is not None and \
-                set(range(self.ndim)) != set(dims_to_collapse):
-            raise ValueError('Cannot partially collapse a coordinate (%s).'
-                             % self.name())
-
-        if np.issubdtype(self.dtype, np.str):
+        if np.issubdtype(self.dtype, np.str_):
             # Collapse the coordinate by serializing the points and
             # bounds as strings.
             def serialize(x):
@@ -1190,28 +1209,20 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
                     'Metadata may not be fully descriptive for {!r}.'
                 warnings.warn(msg.format(self.name()))
 
-            # Create bounds for the new collapsed coordinate.
-            item = self.core_bounds() if self.has_bounds() \
+            # Determine the array library for stacking
+            al = da if self.has_bounds() \
+                and _lazy.is_lazy_data(self.core_bounds()) else np
+
+            item = al.concatenate(self.core_bounds()) if self.has_bounds() \
                 else self.core_points()
-            lower, upper = item.min(), item.max()
-            bounds_dtype = item.dtype
-            # Ensure 2D shape of new bounds.
-            bounds = np.empty((1, 2), 'object')
-            bounds[0, 0] = lower
-            bounds[0, 1] = upper
-            # Create points for the new collapsed coordinate.
-            points_dtype = self.dtype
-            points = (float(lower) + float(upper)) * 0.5
+
+            # Calculate the bounds and points along the right dims
+            bounds = al.stack([item.min(axis=dims_to_collapse),
+                               item.max(axis=dims_to_collapse)]).T
+            points = al.array(bounds.sum(axis=-1) * 0.5, dtype=self.dtype)
 
             # Create the new collapsed coordinate.
-            if is_lazy_data(item):
-                bounds = multidim_lazy_stack(bounds)
-                coord = self.copy(points=points, bounds=bounds)
-            else:
-                bounds = np.concatenate(bounds)
-                bounds = np.array(bounds, dtype=bounds_dtype)
-                coord = self.copy(points=np.array(points, dtype=points_dtype),
-                                  bounds=bounds)
+            coord = self.copy(points=points, bounds=bounds)
         return coord
 
     def _guess_bounds(self, bound_position=0.5):
@@ -1727,7 +1738,7 @@ class DimCoord(Coord):
         # DimCoord always realises the points, to allow monotonicity checks.
         # Ensure it is an actual array, and also make our own copy so that we
         # can make it read-only.
-        points = as_concrete_data(points)
+        points = _lazy.as_concrete_data(points)
         points = np.array(points)
 
         # Check validity requirements for dimension-coordinate points.
@@ -1786,7 +1797,7 @@ class DimCoord(Coord):
     def _bounds_setter(self, bounds):
         if bounds is not None:
             # Ensure we have a realised array of new bounds values.
-            bounds = as_concrete_data(bounds)
+            bounds = _lazy.as_concrete_data(bounds)
             bounds = np.array(bounds)
 
             # Check validity requirements for dimension-coordinate bounds.
@@ -1858,11 +1869,11 @@ class CellMeasure(six.with_metaclass(ABCMeta, CFVariableMixin)):
         Kwargs:
 
         * standard_name:
-            CF standard name of coordinate
+            CF standard name of the coordinate.
         * long_name:
-            Descriptive name of coordinate
+            Descriptive name of the coordinate.
         * var_name:
-            CF variable name of coordinate
+            The netCDF variable name for the coordinate.
         * units
             The :class:`~cf_units.Unit` of the coordinate's values.
             Can be a string, which will be converted to a Unit object.
@@ -1879,7 +1890,7 @@ class CellMeasure(six.with_metaclass(ABCMeta, CFVariableMixin)):
         #: Descriptive name of the coordinate.
         self.long_name = long_name
 
-        #: The CF variable name for the coordinate.
+        #: The netCDF variable name for the coordinate.
         self.var_name = var_name
 
         #: Unit of the quantity that the coordinate represents.
@@ -1912,7 +1923,7 @@ class CellMeasure(six.with_metaclass(ABCMeta, CFVariableMixin)):
         if data is None:
             raise ValueError('The data payload of a CellMeasure may not be '
                              'None; it must be a numpy array or equivalent.')
-        if is_lazy_data(data) and data.dtype.kind in 'biu':
+        if _lazy.is_lazy_data(data) and data.dtype.kind in 'biu':
             # Non-floating cell measures are not valid up to CF v1.7
             msg = ('Cannot create cell measure with lazy data of type {}, as '
                    'integer types are not currently supported.')
