@@ -490,8 +490,7 @@ def _set_attributes(attributes, key, value):
         attributes[str(key)] = value
 
 
-def _load_cube(engine, cf, cf_var, filename):
-    """Create the cube associated with the CF-netCDF data variable."""
+def _get_actual_dtype(cf_var):
     # Figure out what the eventual data type will be after any scale/offset
     # transforms.
     dummy_data = np.zeros(1, dtype=cf_var.dtype)
@@ -499,12 +498,18 @@ def _load_cube(engine, cf, cf_var, filename):
         dummy_data = cf_var.scale_factor * dummy_data
     if hasattr(cf_var, 'add_offset'):
         dummy_data = cf_var.add_offset + dummy_data
+    return dummy_data.dtype
+
+
+def _load_cube(engine, cf, cf_var, filename):
+    """Create the cube associated with the CF-netCDF data variable."""
+    dtype = _get_actual_dtype(cf_var)
 
     # Create cube with deferred data, but no metadata
     fill_value = getattr(cf_var.cf_data, '_FillValue',
                          netCDF4.default_fillvals[cf_var.dtype.str[1:]])
-    proxy = NetCDFDataProxy(cf_var.shape, dummy_data.dtype,
-                            filename, cf_var.cf_name, fill_value)
+    proxy = NetCDFDataProxy(cf_var.shape, dtype, filename, cf_var.cf_name,
+                            fill_value)
     data = as_lazy_data(proxy)
     cube = iris.cube.Cube(data)
 
@@ -1334,6 +1339,27 @@ class Saver(object):
                 dimension_names.append(dim_name)
         return dimension_names
 
+    @staticmethod
+    def cf_valid_var_name(var_name):
+        """
+        Return a valid CF var_name given a potentially invalid name.
+
+        Args:
+
+        * var_name (str):
+            The var_name to normalise
+
+        Returns:
+            A var_name suitable for passing through for variable creation.
+
+        """
+        # Replace invalid charaters with an underscore ("_").
+        var_name = re.sub(r'[^a-zA-Z0-9]', "_", var_name)
+        # Ensure the variable name starts with a letter.
+        if re.match(r'^[^a-zA-Z]', var_name):
+            var_name = 'var_{}'.format(var_name)
+        return var_name
+
     @staticmethod
     def _cf_coord_identity(coord):
         """
@@ -1443,6 +1469,7 @@ class Saver(object):
             # Convert to lower case and replace whitespace by underscores.
             cf_name = '_'.join(cube.name().lower().split())
 
+        cf_name = self.cf_valid_var_name(cf_name)
         return cf_name
 
     def _get_coord_variable_name(self, cube, coord):
@@ -1475,6 +1502,8 @@ class Saver(object):
                     name = 'unknown_scalar'
             # Convert to lower case and replace whitespace by underscores.
             cf_name = '_'.join(name.lower().split())
+
+        cf_name = self.cf_valid_var_name(cf_name)
         return cf_name
 
     def _create_cf_cell_measure_variable(self, cube, dimension_names,
@@ -1570,7 +1599,7 @@ class Saver(object):
         cf_dimensions = [dimension_names[dim] for dim in
                          cube.coord_dims(coord)]
 
-        if np.issubdtype(coord.points.dtype, np.str):
+        if np.issubdtype(coord.points.dtype, np.str_):
             string_dimension_depth = coord.points.dtype.itemsize
             if coord.points.dtype.kind == 'U':
                 string_dimension_depth //= 4
@@ -1837,6 +1866,19 @@ class Saver(object):
                     cf_var_grid.false_easting = cs.false_easting
                     cf_var_grid.false_northing = cs.false_northing
 
+                # albers conical equal area
+                elif isinstance(cs,
+                                iris.coord_systems.AlbersEqualArea):
+                    if cs.ellipsoid:
+                        add_ellipsoid(cs.ellipsoid)
+                    cf_var_grid.longitude_of_central_meridian = (
+                        cs.longitude_of_central_meridian)
+                    cf_var_grid.latitude_of_projection_origin = (
+                        cs.latitude_of_projection_origin)
+                    cf_var_grid.false_easting = cs.false_easting
+                    cf_var_grid.false_northing = cs.false_northing
+                    cf_var_grid.standard_parallel = (cs.standard_parallels)
+
                 # other
                 else:
                     warnings.warn('Unable to represent the horizontal '
@@ -1995,6 +2037,10 @@ class Saver(object):
         if cube.units != 'unknown':
             _setncattr(cf_var, 'units', str(cube.units))
 
+        # Add the CF-netCDF calendar attribute.
+        if cube.units.calendar:
+            _setncattr(cf_var, 'calendar', cube.units.calendar)
+
         # Add data variable-only attribute names to local_keys.
         if local_keys is None:
             local_keys = set()
