@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -78,6 +78,9 @@ try:
     import matplotlib
     matplotlib.use('agg')
     matplotlib.rcdefaults()
+    # Standardise the figure size across matplotlib versions.
+    # This permits matplotlib png image comparison.
+    matplotlib.rcParams['figure.figsize'] = [8.0, 6.0]
     import matplotlib.testing.compare as mcompare
     import matplotlib.pyplot as plt
 except ImportError:
@@ -552,7 +555,6 @@ class IrisTest_nometa(unittest.TestCase):
         msg = msg.format(expected_regexp)
         self.assertTrue(matches, msg)
 
-
     @contextlib.contextmanager
     def assertNoWarningsRegexp(self, expected_regexp=''):
         # Check that no warning matching the given expression is raised.
@@ -782,7 +784,7 @@ class IrisTest_nometa(unittest.TestCase):
             def _create_missing():
                 fname = '{}.png'.format(phash)
                 base_uri = ('https://scitools.github.io/test-iris-imagehash/'
-                            'images/{}')
+                            'images/v4/{}')
                 uri = base_uri.format(fname)
                 hash_fname = os.path.join(image_output_directory, fname)
                 uris = repo.setdefault(unique_id, [])
@@ -817,13 +819,14 @@ class IrisTest_nometa(unittest.TestCase):
                     raise AssertionError(emsg.format(unique_id))
             else:
                 uris = repo[unique_id]
+                # Extract the hex basename strings from the uris.
+                hexes = [os.path.splitext(os.path.basename(uri))[0]
+                         for uri in uris]
                 # Create the expected perceptual image hashes from the uris.
                 to_hash = imagehash.hex_to_hash
-                expected = [to_hash(os.path.splitext(os.path.basename(uri))[0],
-                                    hash_size=_HASH_SIZE)
-                            for uri in uris]
+                expected = [to_hash(uri_hex) for uri_hex in hexes]
 
-                # Calculate the hamming distance vector for the result hash.
+                # Calculate hamming distance vector for the result hash.
                 distances = [e - phash for e in expected]
 
                 if np.all([hd > _HAMMING_DISTANCE for hd in distances]):
@@ -835,7 +838,7 @@ class IrisTest_nometa(unittest.TestCase):
                                'for test {}.')
                         msg = msg.format(phash, distances, unique_id)
                         if _DISPLAY_FIGURES:
-                            emsg = 'Image comparion would have failed: {}'
+                            emsg = 'Image comparison would have failed: {}'
                             print(emsg.format(msg))
                         else:
                             emsg = 'Image comparison failed: {}'
@@ -1104,7 +1107,7 @@ class TestGribMessage(IrisTest):
                         # for each message.
                         self.assertEqual(m1_value, diffs[key][0],
                                          msg=msg.format(key, m1_value,
-                                                         diffs[key][0]))
+                                                        diffs[key][0]))
 
                         self.assertEqual(m2_value, diffs[key][1],
                                          msg=msg.format(key, m2_value,
@@ -1174,7 +1177,7 @@ skip_grib = unittest.skipIf(not GRIB_AVAILABLE,
 
 
 skip_sample_data = unittest.skipIf(not SAMPLE_DATA_AVAILABLE,
-                                   ('Test(s) require "iris_sample_data", '
+                                   ('Test(s) require "iris-sample-data", '
                                     'which is not available.'))
 
 
