@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2014 - 2016, Met Office
+# (C) British Crown Copyright 2014 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -74,9 +74,10 @@ class TestHybridPressure(tests.IrisTest):
         with self.temp_filename(suffix='.nc') as filename, \
                 self.temp_filename(suffix='.nc') as other_filename:
             iris.save(self.cube, filename)
-            cube = iris.load_cube(filename)
+            cube = iris.load_cube(filename, 'air_potential_temperature')
             iris.save(cube, other_filename)
-            other_cube = iris.load_cube(other_filename)
+            other_cube = iris.load_cube(other_filename,
+                                        'air_potential_temperature')
             self.assertEqual(cube, other_cube)
 
 
@@ -120,7 +121,7 @@ class TestSaveMultipleAuxFactories(tests.IrisTest):
         sa.points = sa.points * 10
         with self.temp_filename('.nc') as fname:
             iris.save([hh1, hh2], fname)
-            cubes = iris.load(fname)
+            cubes = iris.load(fname, 'air_temperature')
             cubes = sorted(cubes, key=lambda cube: cube.attributes['cube'])
             self.assertCML(cubes)
 
@@ -203,26 +204,13 @@ class TestLazySave(tests.IrisTest):
     def test_lazy_preserved_save(self):
         fpath = tests.get_data_path(('NetCDF', 'label_and_climate',
                                      'small_FC_167_mon_19601101.nc'))
-        acube = iris.load_cube(fpath)
+        acube = iris.load_cube(fpath, 'air_temperature')
         self.assertTrue(acube.has_lazy_data())
         with self.temp_filename('.nc') as nc_path:
             with Saver(nc_path, 'NETCDF4') as saver:
                 saver.write(acube)
         self.assertTrue(acube.has_lazy_data())
 
-    def test_lazy_mask_preserve_fill_value(self):
-        cube = iris.cube.Cube(np.ma.array([0, 1], mask=[False, True],
-                                          fill_value=-1))
-        with self.temp_filename(suffix='.nc') as filename, \
-                self.temp_filename(suffix='.nc') as other_filename:
-            iris.save(cube, filename, unlimited_dimensions=[])
-            ncube = iris.load_cube(filename)
-            # Lazy save of the masked cube
-            iris.save(ncube, other_filename, unlimited_dimensions=[])
-            ds = nc.Dataset(other_filename, 'r')
-            avar = ds['unknown']
-            self.assertEqual(avar._FillValue, -1)
-
 
 @tests.skip_data
 class TestCellMeasures(tests.IrisTest):
@@ -432,5 +420,14 @@ class TestPackedData(tests.IrisTest):
         self._multi_test('multi_packed_multi_dtype.cdl', multi_dtype=True)
 
 
+class TestScalarCube(tests.IrisTest):
+    def test_scalar_cube_save_load(self):
+        cube = iris.cube.Cube(1, long_name='scalar_cube')
+        with self.temp_filename(suffix='.nc') as fout:
+            iris.save(cube, fout)
+            scalar_cube = iris.load_cube(fout)
+            self.assertEqual(scalar_cube.name(), 'scalar_cube')
+
+
 if __name__ == "__main__":
     tests.main()
