@@ -33,17 +33,12 @@ import iris.tests.stock
 from iris.coord_systems import *
 
 
-
-
 def osgb():
     return TransverseMercator(latitude_of_projection_origin=49, longitude_of_central_meridian=-2,
                               false_easting=-400, false_northing=100,
                               scale_factor_at_central_meridian=0.9996012717,
                               ellipsoid=GeogCS(6377563.396, 6356256.909))
 
-def merc():
-    return Mercator(longitude_of_projection_origin=90.0,
-                    ellipsoid=GeogCS(6377563.396, 6356256.909))
 
 def stereo():
     return Stereographic(central_lat=-90, central_lon=-45,
@@ -391,58 +386,5 @@ class Test_LambertConformal(tests.GraphicsTest):
         self.assertEqual(ccrs.cutoff, 30)
 
 
-class Test_Mercator_construction(tests.IrisTest):
-    def test_merc(self):
-        tm = merc()
-        self.assertXMLElement(tm, ("coord_systems", "Mercator.xml"))
-
-
-class Test_Mercator_repr(tests.IrisTest):
-    def test_merc(self):
-        tm = merc()
-        expected = "Mercator(longitude_of_projection_origin=90.0, "\
-                   "ellipsoid=GeogCS(semi_major_axis=6377563.396, "\
-                   "semi_minor_axis=6356256.909))"
-        self.assertEqual(expected, repr(tm))
-
-
-class Test_Mercator_as_cartopy_crs(tests.IrisTest):
-    def test_as_cartopy_crs(self):
-        longitude_of_projection_origin = 90.0
-        ellipsoid = GeogCS(semi_major_axis=6377563.396,
-                           semi_minor_axis=6356256.909)
-
-        merc_cs = Mercator(
-            longitude_of_projection_origin,
-            ellipsoid=ellipsoid)
-
-        expected = ccrs.Mercator(
-            central_longitude=longitude_of_projection_origin,
-            globe=ccrs.Globe(semimajor_axis=6377563.396,
-                             semiminor_axis=6356256.909, ellipse=None))
-
-        res = merc_cs.as_cartopy_crs()
-        self.assertEqual(res, expected)
-
-
-class Test_Mercator_as_cartopy_projection(tests.IrisTest):
-    def test_as_cartopy_projection(self):
-        longitude_of_projection_origin = 90.0
-        ellipsoid = GeogCS(semi_major_axis=6377563.396,
-                           semi_minor_axis=6356256.909)
-
-        merc_cs = Mercator(
-            longitude_of_projection_origin,
-            ellipsoid=ellipsoid)
-
-        expected = ccrs.Mercator(
-            central_longitude=longitude_of_projection_origin,
-            globe=ccrs.Globe(semimajor_axis=6377563.396,
-                             semiminor_axis=6356256.909, ellipse=None))
-
-        res = merc_cs.as_cartopy_projection()
-        self.assertEqual(res, expected)
-
-
 if __name__ == "__main__":
     tests.main()
