@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -28,12 +28,10 @@ import tempfile
 import cf_units
 import numpy as np
 
-import iris
 import iris.coords
 import iris.coord_systems
-import iris.fileformats.pp as ff_pp
+import iris.fileformats.pp
 from iris.fileformats.pp import PPField3
-import iris.io
 from iris.tests import mock
 import iris.tests.pp as pp
 import iris.util
@@ -90,30 +88,6 @@ class TestPPSave(tests.IrisTest, pp.PPTest):
         with self.cube_save_test(reference_txt_path, reference_cubes=cubes) as temp_pp_path:
             iris.save(cubes, temp_pp_path)
 
-    def test_user_pp_save_rules(self):
-        # Test pp save rules with user rules.
-        
-        #create a user rules file
-        user_rules_filename = iris.util.create_temp_filename(suffix='.txt')
-        try:
-            with open(user_rules_filename, "wt") as user_rules_file:
-                user_rules_file.write("IF\ncm.standard_name == 'air_temperature'\nTHEN\npp.lbuser[3] = 9222")
-            with iris.fileformats.rules._disable_deprecation_warnings():
-                iris.fileformats.pp.add_save_rules(user_rules_filename)
-            try:
-                #read pp
-                in_filename = tests.get_data_path(('PP', 'simple_pp', 'global.pp'))
-                cubes = iris.load(in_filename, callback=itab_callback)
-
-                reference_txt_path = tests.get_result_path(('cube_to_pp', 'user_rules.txt'))
-                with self.cube_save_test(reference_txt_path, reference_cubes=cubes) as temp_pp_path:
-                    iris.save(cubes, temp_pp_path)
-
-            finally:
-                iris.fileformats.pp.reset_save_rules()
-        finally:
-            os.remove(user_rules_filename)
-
     def test_pp_append_singles(self):
         # Test pp append saving - single cubes.
         
@@ -207,12 +181,13 @@ class TestPPSave(tests.IrisTest, pp.PPTest):
         new_unit = cf_units.Unit('hours since 1970-01-01 00:00:00',
                                   calendar=cf_units.CALENDAR_365_DAY)
         cube.coord('time').units = new_unit
+        # Add an extra "fill_value" property, as used by the save rules.
+        cube.fill_value = None
         pp_field = mock.MagicMock(spec=PPField3)
-        iris.fileformats.pp._ensure_save_rules_loaded()
-        iris.fileformats.pp._save_rules.verify(cube, pp_field)
+        iris.fileformats.pp_save_rules.verify(cube, pp_field)
         self.assertEqual(pp_field.lbtim.ic, 4)
 
-            
+
 class FakePPEnvironment(object):
     ''' fake a minimal PP environment for use in cross-section coords, as in PP save rules '''
     y = [1, 2, 3, 4]
@@ -340,7 +315,7 @@ def fields_from_cube(cubes):
         fh.seek(0)
         
         # load in the saved pp fields and check the appropriate metadata
-        for field in ff_pp.load(tmp_file.name):
+        for field in iris.fileformats.pp.load(tmp_file.name):
             yield field
             
 
