@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2013 - 2017, Met Office
+# (C) British Crown Copyright 2013 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -27,9 +27,9 @@ import datetime
 import unittest
 
 import cf_units
+import cftime
 import matplotlib.units
 import netCDF4
-import netcdftime
 import numpy as np
 
 
@@ -101,18 +101,12 @@ class TestAsSeries(tests.IrisTest):
         time_coord = DimCoord([0, 100.1, 200.2, 300.3, 400.4],
                               long_name="time", units=time_unit)
         cube.add_dim_coord(time_coord, 0)
-        if netCDF4.__version__ > '1.2.4':
-            expected_index = [netcdftime.Datetime360Day(2000, 1, 1, 0, 0),
-                              netcdftime.Datetime360Day(2000, 4, 11, 2, 24),
-                              netcdftime.Datetime360Day(2000, 7, 21, 4, 48),
-                              netcdftime.Datetime360Day(2000, 11, 1, 7, 12),
-                              netcdftime.Datetime360Day(2001, 2, 11, 9, 36)]
-        else:
-            expected_index = [netcdftime.datetime(2000, 1, 1, 0, 0),
-                              netcdftime.datetime(2000, 4, 11, 2, 24),
-                              netcdftime.datetime(2000, 7, 21, 4, 48),
-                              netcdftime.datetime(2000, 11, 1, 7, 12),
-                              netcdftime.datetime(2001, 2, 11, 9, 36)]
+        expected_index = [cftime.Datetime360Day(2000, 1, 1, 0, 0),
+                          cftime.Datetime360Day(2000, 4, 11, 2, 24),
+                          cftime.Datetime360Day(2000, 7, 21, 4, 48),
+                          cftime.Datetime360Day(2000, 11, 1, 7, 12),
+                          cftime.Datetime360Day(2001, 2, 11, 9, 36)]
+
         series = iris.pandas.as_series(cube)
         self.assertArrayEqual(series, cube.data)
         self.assertArrayEqual(series.index, expected_index)
@@ -244,12 +238,9 @@ class TestAsDataFrame(tests.IrisTest):
         time_coord = DimCoord([100.1, 200.2], long_name="time",
                               units=time_unit)
         cube.add_dim_coord(time_coord, 0)
-        if netCDF4.__version__ > '1.2.4':
-            expected_index = [netcdftime.Datetime360Day(2000, 4, 11, 2, 24),
-                              netcdftime.Datetime360Day(2000, 7, 21, 4, 48)]
-        else:
-            expected_index = [netcdftime.datetime(2000, 4, 11, 2, 24),
-                              netcdftime.datetime(2000, 7, 21, 4, 48)]
+        expected_index = [cftime.Datetime360Day(2000, 4, 11, 2, 24),
+                          cftime.Datetime360Day(2000, 7, 21, 4, 48)]
+
         expected_columns = [0, 1, 2, 3, 4]
         data_frame = iris.pandas.as_data_frame(cube)
         self.assertArrayEqual(data_frame, cube.data)
@@ -347,14 +338,14 @@ class TestSeriesAsCube(tests.IrisTest):
             tests.get_result_path(('pandas', 'as_cube',
                                    'series_datetime_gregorian.cml')))
 
-    def test_series_netcdftime_360(self):
+    def test_series_cftime_360(self):
         series = pandas.Series(
             [0, 1, 2, 3, 4],
-            index=[netcdftime.datetime(2001, 1, 1, 1, 1, 1),
-                   netcdftime.datetime(2002, 2, 2, 2, 2, 2),
-                   netcdftime.datetime(2003, 3, 3, 3, 3, 3),
-                   netcdftime.datetime(2004, 4, 4, 4, 4, 4),
-                   netcdftime.datetime(2005, 5, 5, 5, 5, 5)])
+            index=[cftime.datetime(2001, 1, 1, 1, 1, 1),
+                   cftime.datetime(2002, 2, 2, 2, 2, 2),
+                   cftime.datetime(2003, 3, 3, 3, 3, 3),
+                   cftime.datetime(2004, 4, 4, 4, 4, 4),
+                   cftime.datetime(2005, 5, 5, 5, 5, 5)])
         self.assertCML(
             iris.pandas.as_cube(series,
                                 calendars={0: cf_units.CALENDAR_360_DAY}),
@@ -407,12 +398,12 @@ class TestDataFrameAsCube(tests.IrisTest):
             tests.get_result_path(('pandas', 'as_cube',
                                    'data_frame_masked.cml')))
 
-    def test_data_frame_netcdftime_360(self):
+    def test_data_frame_cftime_360(self):
         data_frame = pandas.DataFrame(
             [[0, 1, 2, 3, 4],
              [5, 6, 7, 8, 9]],
-            index=[netcdftime.datetime(2001, 1, 1, 1, 1, 1),
-                   netcdftime.datetime(2002, 2, 2, 2, 2, 2)],
+            index=[cftime.datetime(2001, 1, 1, 1, 1, 1),
+                   cftime.datetime(2002, 2, 2, 2, 2, 2)],
             columns=[10, 11, 12, 13, 14])
         self.assertCML(
             iris.pandas.as_cube(
