@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -25,6 +25,7 @@ import six
 
 import abc
 import collections
+from contextlib import contextmanager
 import copy
 import functools
 import inspect
@@ -936,16 +937,44 @@ def format_array(arr):
     For customisations, use the :mod:`numpy.core.arrayprint` directly.
 
     """
-    if arr.size > 85:
-        summary_insert = "..., "
-    else:
-        summary_insert = ""
+
+    summary_insert = ""
+    summary_threshold = 85
+    edge_items = 3
     ffunc = str
-    return np.core.arrayprint._formatArray(arr, ffunc, len(arr.shape),
-                                           max_line_len=50,
-                                           next_line_prefix='\t\t',
-                                           separator=', ', edge_items=3,
-                                           summary_insert=summary_insert)[:-1]
+    formatArray = np.core.arrayprint._formatArray
+    max_line_len = 50
+    legacy = '1.13'
+    if arr.size > summary_threshold:
+        summary_insert = '...'
+    options = np.get_printoptions()
+    options['legacy'] = legacy
+    with _printopts_context(**options):
+        result = formatArray(
+            arr, ffunc, max_line_len,
+            next_line_prefix='\t\t', separator=', ',
+            edge_items=edge_items,
+            summary_insert=summary_insert,
+            legacy=legacy)
+
+    return result
+
+
+@contextmanager
+def _printopts_context(**kwargs):
+    """
+    Update the numpy printoptions for the life of this context manager.
+
+    Note: this function can be removed with numpy>=1.15 thanks to
+          https://github.com/numpy/numpy/pull/10406
+
+    """
+    original_opts = np.get_printoptions()
+    np.set_printoptions(**kwargs)
+    try:
+        yield
+    finally:
+        np.set_printoptions(**original_opts)
 
 
 def new_axis(src_cube, scalar_coord=None):
